@@ -117,7 +117,7 @@
     <message>
         <location filename="../src/data/data.cpp" line="169"/>
         <source>JPEG images</source>
-        <translation>JPEG fájlok</translation>
+        <translation>JPEG képek</translation>
     </message>
     <message>
         <location filename="../src/data/data.cpp" line="170"/>
@@ -295,7 +295,7 @@
         <location filename="../src/GUI/fileselectwidget.cpp" line="46"/>
         <location filename="../src/GUI/fileselectwidget.cpp" line="51"/>
         <source>Select file</source>
-        <translation>Fájl választása</translation>
+        <translation>Fájl kiválasztása</translation>
     </message>
     <message>
         <location filename="../src/GUI/fileselectwidget.cpp" line="61"/>
@@ -305,12 +305,12 @@
     <message>
         <location filename="../src/GUI/fileselectwidget.cpp" line="71"/>
         <source>%1 is a directory.</source>
-        <translation>A(z) %1 egy mappa.</translation>
+        <translation>%1 egy mappa.</translation>
     </message>
     <message>
         <location filename="../src/GUI/fileselectwidget.cpp" line="75"/>
         <source>%1 is not writable.</source>
-        <translation>A(z) %1 írásvédett.</translation>
+        <translation>%1 írásvédett.</translation>
     </message>
 </context>
 <context>
@@ -356,7 +356,7 @@
         <location filename="../src/GUI/gui.cpp" line="974"/>
         <location filename="../src/GUI/gui.cpp" line="992"/>
         <source>Paths</source>
-        <translation>Adatmappák</translation>
+        <translation>Elérési útvonalak</translation>
     </message>
     <message>
         <location filename="../src/GUI/gui.cpp" line="211"/>
@@ -369,37 +369,37 @@
         <location filename="../src/GUI/gui.cpp" line="215"/>
         <location filename="../src/GUI/gui.cpp" line="901"/>
         <source>About GPXSee</source>
-        <translation>GPXSee névjegye</translation>
+        <translation>A GPXSee névjegye</translation>
     </message>
     <message>
         <location filename="../src/GUI/gui.cpp" line="221"/>
         <source>Open...</source>
-        <translation>Megnyitás...</translation>
+        <translation>Megnyitás…</translation>
     </message>
     <message>
         <location filename="../src/GUI/gui.cpp" line="228"/>
         <source>Open directory...</source>
-        <translation>Könyvtár megnyitása...</translation>
+        <translation>Könyvtár megnyitása…</translation>
     </message>
     <message>
         <location filename="../src/GUI/gui.cpp" line="233"/>
         <source>Print...</source>
-        <translation>Nyomtatás...</translation>
+        <translation>Nyomtatás…</translation>
     </message>
     <message>
         <location filename="../src/GUI/gui.cpp" line="239"/>
         <source>Export to PDF...</source>
-        <translation>Exportálás PDF-be...</translation>
+        <translation>Exportálás PDF-be…</translation>
     </message>
     <message>
         <location filename="../src/GUI/gui.cpp" line="246"/>
         <source>Export to PNG...</source>
-        <translation>Exportálás PNG-be...</translation>
+        <translation>Exportálás PNG-be…</translation>
     </message>
     <message>
         <location filename="../src/GUI/gui.cpp" line="253"/>
         <source>Close</source>
-        <translation>Fájl bezárása</translation>
+        <translation>Bezárás</translation>
     </message>
     <message>
         <location filename="../src/GUI/gui.cpp" line="260"/>
@@ -409,7 +409,7 @@
     <message>
         <location filename="../src/GUI/gui.cpp" line="266"/>
         <source>Statistics...</source>
-        <translation>Statisztika...</translation>
+        <translation>Statisztika…</translation>
     </message>
     <message>
         <location filename="../src/GUI/gui.cpp" line="276"/>
@@ -419,7 +419,7 @@
     <message>
         <location filename="../src/GUI/gui.cpp" line="288"/>
         <source>Load POI file...</source>
-        <translation>POI fájl betöltése...</translation>
+        <translation>POI fájl betöltése…</translation>
     </message>
     <message>
         <location filename="../src/GUI/gui.cpp" line="292"/>
@@ -429,7 +429,7 @@
     <message>
         <location filename="../src/GUI/gui.cpp" line="297"/>
         <source>Unselect all files</source>
-        <translation>Összes kijelölés megszüntetése</translation>
+        <translation>Összes kijelölésének visszavonása</translation>
     </message>
     <message>
         <location filename="../src/GUI/gui.cpp" line="302"/>
@@ -459,12 +459,12 @@
     <message>
         <location filename="../src/GUI/gui.cpp" line="339"/>
         <source>Load map...</source>
-        <translation>Térkép betöltése...</translation>
+        <translation>Térkép betöltése…</translation>
     </message>
     <message>
         <location filename="../src/GUI/gui.cpp" line="344"/>
         <source>Load map directory...</source>
-        <translation>Térképmappa megadása...</translation>
+        <translation>Térképmappa megadása…</translation>
     </message>
     <message>
         <location filename="../src/GUI/gui.cpp" line="347"/>
@@ -683,7 +683,7 @@
     <message>
         <location filename="../src/GUI/gui.cpp" line="604"/>
         <source>Options...</source>
-        <translation>Beállítások...</translation>
+        <translation>Beállítások…</translation>
     </message>
     <message>
         <location filename="../src/GUI/gui.cpp" line="611"/>
