@@ -1,18 +1,16 @@
 #include <QDir>
 #include <QFileInfo>
-#include "common/dem.h"
+#include "map/map.h"
 #include "waypoint.h"
 
 bool Waypoint::_useDEM = false;
 bool Waypoint::_show2ndElevation = false;
 QHash<QString, QPixmap> Waypoint::_symbolIcons;
 
-QPair<qreal, qreal> Waypoint::elevations() const
+QPair<qreal, qreal> Waypoint::elevations(Map *map) const
 {
 	if (_useDEM) {
-		DEM::lock();
-		qreal dem = DEM::elevation(coordinates());
-		DEM::unlock();
+		qreal dem = map->elevation(coordinates());
 		if (!std::isnan(dem))
 			return QPair<qreal, qreal>(dem, _show2ndElevation ? elevation()
 			  : NAN);
@@ -20,12 +18,10 @@ QPair<qreal, qreal> Waypoint::elevations() const
 			return QPair<qreal, qreal>(elevation(), NAN);
 	} else {
 		if (hasElevation()) {
-			DEM::lock();
-			qreal dem = _show2ndElevation ? DEM::elevation(coordinates()) : NAN;
-			DEM::unlock();
+			qreal dem = _show2ndElevation ? map->elevation(coordinates()) : NAN;
 			return QPair<qreal, qreal>(elevation(), dem);
 		} else
-			return QPair<qreal, qreal>(DEM::elevation(coordinates()), NAN);
+			return QPair<qreal, qreal>(map->elevation(coordinates()), NAN);
 	}
 }
 
